cmd

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 31, 2026 License: Apache-2.0 Imports: 11 Imported by: 0

Documentation

Overview

Package cmd wires the docdag CLI: a cobra command tree over the document graph. It is the only place that maps errors onto process exit codes.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Execute

func Execute() int

Execute runs the CLI and returns the process exit code.

Types

This section is empty.

Directories

Path Synopsis
Command docdag extracts a typed directed graph from a directory of Markdown documents, enforces DAG invariants on it and answers graph queries.
Command docdag extracts a typed directed graph from a directory of Markdown documents, enforces DAG invariants on it and answers graph queries.

Jump to